@@ -460,7 +460,7 @@ KFilePreviewGeneratorPrivate::KFilePreviewGeneratorPrivate(KFilePreviewGenerator
         delayedIconUpdate();
     });
 
-    KConfigGroup globalConfig(KSharedConfig::openConfig(QStringLiteral("dolphinrc")), "PreviewSettings");
+    KConfigGroup globalConfig(KSharedConfig::openConfig(QStringLiteral("dolphinrc")), QStringLiteral("PreviewSettings"));
     m_enabledPlugins =
         globalConfig.readEntry("Plugins", QStringList{QStringLiteral("directorythumbnail"), QStringLiteral("imagethumbnail"), QStringLiteral("jpegthumbnail")});
 
@@ -583,7 +583,9 @@ void KFilePreviewGeneratorPrivate::addToPreviewQueue(const KFileItem &item, cons
             return; // the sequence index does not match the one we want
         }
 
-        m_sequenceIndices.erase(it);
+        if (it != m_sequenceIndices.end()) {
+            m_sequenceIndices.erase(it);
+        }
     }
 
     if (!m_previewShown) {
@@ -887,7 +889,7 @@ void KFilePreviewGeneratorPrivate::applyCutItemEffect(const KFileItemList &items
         if (cutUrls.contains(item.url())) {
             const QModelIndex index = dirModel->indexForItem(item);
             const QVariant value = dirModel->data(index, Qt::DecorationRole);
-            if (value.type() == QVariant::Icon) {
+            if (value.typeId() == QMetaType::QIcon) {
                 const QIcon icon(qvariant_cast<QIcon>(value));
                 const QSize actualSize = icon.actualSize(m_viewAdapter->iconSize());
                 QPixmap pixmap = icon.pixmap(actualSize);
@@ -1178,13 +1180,6 @@ bool KFilePreviewGenerator::isPreviewShown() const
     return d->m_previewShown;
 }
 
-#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 3)
-void KFilePreviewGenerator::updatePreviews()
-{
-    updateIcons();
-}
-#endif
-
 void KFilePreviewGenerator::updateIcons()
 {
     d->killPreviewJobs();
