@@ -84,7 +84,9 @@ static KIO::Job *putDataAsyncTo(const QUrl &url, const QByteArray &data, QWidget
     KIO::Job *job = KIO::storedPut(data, url, -1, flags);
     QObject::connect(job, &KIO::Job::result, [url](KJob *job) {
         if (job->error() == KJob::NoError) {
+#ifdef WITH_QTDBUS
             org::kde::KDirNotify::emitFilesAdded(url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash));
+#endif
         }
     });
     KJobWidgets::setWindow(job, widget);
@@ -253,7 +255,7 @@ KIOWIDGETS_EXPORT QString KIO::pasteActionText(const QMimeData *mimeData, bool *
         } else if (!urls.isEmpty()) {
             text = i18ncp("@action:inmenu", "Paste One Item", "Paste %1 Items", urls.count());
         } else {
-            text = i18nc("@action:inmenu", "Paste Clipboard Contents...");
+            text = i18nc("@action:inmenu", "Paste Clipboard Contents…");
         }
     } else {
         *enable = false;
